# vim: set ts=4 sw=4 et:
# Copyright (c) 2005-2010 oc2pus, 2011 Pascal Bleser
# This file and all modifications and additions to the pristine
# package are under the same license as the package itself.
#
# Please submit bugfixes or comments to packman@links2linux.de

%define ruby_sitedir %(ruby -rrbconfig -e 'puts Config::CONFIG["sitelibdir"]')

%{!?python_sitelib:  %global python_sitelib  %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib(1))")}

Name:           ecasound
Summary:        Multitrack audio processing tool
Version:        2.8.1
Release:        0.pm.1.15
License:        GNU General Public License version 2 or later (GPLv2 or later)
Group:          Productivity/Multimedia/Sound/Editors and Convertors
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
URL:            http://ecasound.seul.org/
# http://ecasound.seul.org/download/ecasound-%{version}.tar.gz
Source:         ecasound-%{version}.tar.bz2
BuildRequires:  alsa-devel
BuildRequires:  arts-devel
BuildRequires:  audiofile-devel
BuildRequires:  fdupes
BuildRequires:  flac-devel
BuildRequires:  glib2-devel
BuildRequires:  ladspa
BuildRequires:  libjack-devel
BuildRequires:  liblo-devel
BuildRequires:  liboil-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libstdc++-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  python-devel
BuildRequires:  ruby
BuildRequires:  readline-devel
BuildRequires:  libsndfile-devel
Requires:       alsa
Requires:       jack
Requires:       ladspa
BuildRequires:  alsa jack ladspa
%py_requires

%description
Ecasound is a software package designed for multitrack audio
processing. It can be used for simple tasks like audio playback,
recording and format conversions, as well as for multitrack effect
processing, mixing, recording and signal recycling. Ecasound
supports a wide range of audio inputs, outputs and effect
algorithms. Several open-source audio packages, like for instance
ALSA, OSS, mpg123, lame, libaudiofile and MikMod, are directly
supported. One of the advantages of ecasound's chain-based design
is that effects can easily be combined both in series and in
parallel. Oscillators and MIDI-CCs can be used for controlling
effect parameters. Included user-interfaces are ecasound - a
versatile console mode interface, qtecasound - a Qt-based
X-interface and various command-line utils suitable for batch
processing.

%package -n libecasound-devel
Summary:        Library header files for ecasound
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       alsa-devel
Requires:       jack-devel
Requires:       libsndfile-devel
Provides:       ecasound-devel = 2.4.5
Obsoletes:      ecasound-devel < 2.4.5

%description -n libecasound-devel
Headers files needed for compiling other programs against ecasound
libraries.

%package -n python-ecasound
Summary:        Python Bindings to the Ecasound Control Interface
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
%if %suse_version >= 1110
Requires:       python-base >= %{py_ver}
%else
Requires:       python >= %{py_ver}
%endif
Provides:       pyecasound = 2.4.5
Obsoletes:      pyecasound < 2.4.5

%description -n python-ecasound
Python bindings to the Ecasound control interface.

%package -n ruby-ecasound
Summary:        Ruby Bindings to the Ecasound Control Interface
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       ruby

%description -n ruby-ecasound
Ruby bindings to the Ecasound control interface.

%package doc
Summary:        User documentation for the Ecasound control interface
Group:          Documentation/HTML
Requires:       %{name} = %{version}

%description doc
User documentation for the Ecasound control interface.

%prep
%setup -q

%if 0%{suse_version} == 1100
%__sed -i -e 's|ncurses/term.h|ncursesw/term.h|g' %{name}/eca-curses.cpp
%__sed -i -e 's|ncurses/term.h|ncursesw/term.h|g' %{name}/textdebug.cpp
%__sed -i -e 's|ncurses/term.h|ncursesw/term.h|g' ecatools/ecasignalview.cpp
%endif

%build
export CFLAGS="$RPM_OPT_FLAGS -fPIC -DPIC"
export CXXFLAGS="$RPM_OPT_FLAGS"
%configure \
    --enable-shared \
    --enable-static \
    --with-pic \
    --enable-sys-readline \
    --enable-liboil \
    --enable-liblo \
    --with-python-modules=%{_libdir}/python%{py_ver} \
    --with-python-includes=%{_includedir}/python%{py_ver}

%__make %{?_smp_flags}

%install
%makeinstall

# clean ups
find Documentation -name 'Makefile*' | xargs %__rm
find examples -name 'Makefile*'      | xargs %__rm
%__rm Documentation/*.1
%__rm %{buildroot}%{_libdir}/lib*.la
#%__rm %{buildroot}%{_libdir}/lib*.a

%__chmod 644 %{buildroot}%{python_sitearch}/*.py
%__chmod 644 %{buildroot}%{ruby_sitedir}/%{name}.rb

%fdupes -s %{buildroot}%{_mandir}

%clean
%{?buildroot:%__rm -rf "%{buildroot}"}

%files
%defattr(-, root, root)
%doc AUTHORS BUGS COPYING COPYING.GPL COPYING.LGPL NEWS README TODO
%doc examples
%{_bindir}/ecasound
%{_bindir}/ecaconvert
%{_bindir}/ecafixdc
%{_bindir}/ecalength
%{_bindir}/ecamonitor
%{_bindir}/ecanormalize
%{_bindir}/ecaplay
%{_bindir}/ecasignalview
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}.el
%config %{_datadir}/%{name}/ecasoundrc
%config %{_datadir}/%{name}/generic_oscillators
%config %{_datadir}/%{name}/effect_presets
%doc %{_mandir}/*/*

%files -n libecasound-devel
%defattr(-, root, root)
%{_includedir}/kvutils
%{_includedir}/libecasound
%{_includedir}/libecasoundc
%{_bindir}/libecasound-config
%{_bindir}/libecasoundc-config
%{_libdir}/libecasound.a
%{_libdir}/libecasoundc.a
%{_libdir}/libkvutils.a

%files -n python-ecasound
%defattr(-,root,root)
%{python_sitearch}/*.py*
%{python_sitearch}/*.so

%files -n ruby-ecasound
%defattr(-,root,root)
%{ruby_sitedir}/*

%files doc
%defattr(-,root,root)
%doc Documentation/*

%changelog
* Sun May 22 2011 pascal.bleser@opensuse.org
- update to 2.8.1
* Mon Feb 22 2010 toni@links2linux.de
- update to 2.7.1
- Various bugfixes, including a fix to a bug causing audible glitches
  with old versions of ALSA and certain hardware drivers.
* Tue Oct 27 2009 toni@links2linux.de
- update to 2.7.0
- An initial Open Sound Control (OSC) interface for parameter control has been
  added. New '-chorder' and '-eadb' options and a 'cop-get' interactive mode
  command have been added. Optional build time support has been added for using
  liboil to optimize inner loops, giving a small performance boost to many common
  use-scenarios. Various bugs have been fixed in JACK support, MP3 output, and
  option parsing. There are fixes to build problems in Mac OS X.
* Tue Feb 10 2009 toni@links2linux.de
- update to 2.6.0
* Thu Aug 28 2008 toni@links2linux.de
- update to 2.5.2
* Thu Aug 21 2008 toni@links2linux.de
- update to 2.5.1
* Sun Aug 17 2008 toni@links2linux.de
- update to 2.5.0
* Tue Aug 14 2007 toni@links2linux.de
- update to 2.4.6.1
* Mon Dec 18 2006 toni@links2linux.de
- update to 2.4.5
* Tue Sep 19 2006 toni@links2linux.de
- build for packman
* Sat Jan 28 2006 oc2pus@arcor.de 2.4.4-0.oc2pus.1
- update to 2.4.4
- added subpackage ruby-ecasound
* Fri Nov 18 2005 oc2pus@arcor.de 2.4.3-0.oc2pus.3
- rebuild SuSE-10.0
* Thu Sep  8 2005 oc2pus@arcor.de 2.4.3-0.oc2pus.2
- corrected dependency gpp ==> libgpp
* Tue Aug 23 2005 oc2pus@arcor.de 2.4.3-0.oc2pus.1
- update to 2.4.3
- repackes as tar.bz2
* Fri Aug 12 2005 oc2pus@arcor.de 2.4.2-0.oc2pus.1
- update to 2.4.2
- added packager-tag
* Wed Apr 13 2005 oc2pus@arcor.de 2.4.1-0.oc2pus.1
- update to 2.4.1
- based on SuSE spec-file ecasound-2.3.2
